Package ru.yojo.codegen.mapper
Class ExistingObjectHandler
java.lang.Object
ru.yojo.codegen.mapper.ExistingObjectHandler
- All Implemented Interfaces:
PropertyTypeHandler
Handles existing object references (format: existing in YAML).
Sets up the type to reference an already existing Java class.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanChecks if this handler can process the given property definition.voidHandles the property by populating VariableProperties with the appropriate type, imports, and other metadata.
-
Constructor Details
-
ExistingObjectHandler
public ExistingObjectHandler()
-
-
Method Details
-
canHandle
Description copied from interface:PropertyTypeHandlerChecks if this handler can process the given property definition.- Specified by:
canHandlein interfacePropertyTypeHandler- Parameters:
ctx- bundled context with all parameters- Returns:
- true if this handler can handle the property
-
handle
Description copied from interface:PropertyTypeHandlerHandles the property by populating VariableProperties with the appropriate type, imports, and other metadata.- Specified by:
handlein interfacePropertyTypeHandler- Parameters:
ctx- bundled context with all parameters
-