Package ru.yojo.codegen.exception
Class SchemaFillException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
ru.yojo.codegen.exception.SchemaFillException
- All Implemented Interfaces:
Serializable
Thrown when schema processing fails due to invalid or unsupported configuration in the AsyncAPI contract.
Typical causes:
- Missing required attributes (e.g.,
typein schema) - Inconsistent validation group configuration
- Unresolvable references
- See Also:
-
Constructor Summary
ConstructorsConstructorDescriptionSchemaFillException(String message) Constructs a new exception with the specified detail message. -
Method Summary
Methods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
SchemaFillException
Constructs a new exception with the specified detail message.- Parameters:
message- descriptive error message
-