Package ru.yojo.codegen.mapper
Class FormatObjectHandler
java.lang.Object
ru.yojo.codegen.mapper.FormatObjectHandler
- All Implemented Interfaces:
PropertyTypeHandler
Handles properties with
type: object and a recognized format value
(e.g., type: object, format: uuid → sets format to uuid).
This is a special case where the "object" type is used as a container for a well-known format that maps to a specific Java type (e.g., UUID, LocalDate).
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanChecks if this handler can process the given property definition.voidHandles the property by populating VariableProperties with the appropriate type, imports, and other metadata.
-
Constructor Details
-
FormatObjectHandler
public FormatObjectHandler()
-
-
Method Details
-
canHandle
Description copied from interface:PropertyTypeHandlerChecks if this handler can process the given property definition.- Specified by:
canHandlein interfacePropertyTypeHandler- Parameters:
ctx- bundled context with all parameters- Returns:
- true if this handler can handle the property
-
handle
Description copied from interface:PropertyTypeHandlerHandles the property by populating VariableProperties with the appropriate type, imports, and other metadata.- Specified by:
handlein interfacePropertyTypeHandler- Parameters:
ctx- bundled context with all parameters
-