Package ru.yojo.codegen.mapper
Record Class PropertyResolutionContext
java.lang.Object
java.lang.Record
ru.yojo.codegen.mapper.PropertyResolutionContext
- Record Components:
schemaName- name of the containing schemavariableProperties- target field container to populatecurrentSchema- full schema map where this property is definedschemas- global map of all known schemaspropertyName- field name in YAMLpropertiesMap- raw field definition from YAMLprocessContext- current generation contextinnerSchemas- accumulator for discovered inner schemas
public record PropertyResolutionContext(String schemaName, VariableProperties variableProperties, Map<String,Object> currentSchema, Map<String,Object> schemas, String propertyName, Map<String,Object> propertiesMap, ProcessContext processContext, Map<String,Object> innerSchemas)
extends Record
Context object that bundles parameters passed to
PropertyTypeHandler methods.
Reduces method parameter count and simplifies the handler interface.
-
Constructor Summary
ConstructorsConstructorDescriptionPropertyResolutionContext(String schemaName, VariableProperties variableProperties, Map<String, Object> currentSchema, Map<String, Object> schemas, String propertyName, Map<String, Object> propertiesMap, ProcessContext processContext, Map<String, Object> innerSchemas) Creates an instance of aPropertyResolutionContextrecord class. -
Method Summary
Modifier and TypeMethodDescriptionReturns the value of thecurrentSchemarecord component.final booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.Returns the value of theinnerSchemasrecord component.Returns the value of theprocessContextrecord component.Returns the value of thepropertiesMaprecord component.Returns the value of thepropertyNamerecord component.Returns the value of theschemaNamerecord component.schemas()Returns the value of theschemasrecord component.final StringtoString()Returns a string representation of this record class.Returns the value of thevariablePropertiesrecord component.
-
Constructor Details
-
PropertyResolutionContext
public PropertyResolutionContext(String schemaName, VariableProperties variableProperties, Map<String, Object> currentSchema, Map<String, Object> schemas, String propertyName, Map<String, Object> propertiesMap, ProcessContext processContext, Map<String, Object> innerSchemas) Creates an instance of aPropertyResolutionContextrecord class.- Parameters:
schemaName- the value for theschemaNamerecord componentvariableProperties- the value for thevariablePropertiesrecord componentcurrentSchema- the value for thecurrentSchemarecord componentschemas- the value for theschemasrecord componentpropertyName- the value for thepropertyNamerecord componentpropertiesMap- the value for thepropertiesMaprecord componentprocessContext- the value for theprocessContextrecord componentinnerSchemas- the value for theinnerSchemasrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
schemaName
Returns the value of theschemaNamerecord component.- Returns:
- the value of the
schemaNamerecord component
-
variableProperties
Returns the value of thevariablePropertiesrecord component.- Returns:
- the value of the
variablePropertiesrecord component
-
currentSchema
Returns the value of thecurrentSchemarecord component.- Returns:
- the value of the
currentSchemarecord component
-
schemas
Returns the value of theschemasrecord component.- Returns:
- the value of the
schemasrecord component
-
propertyName
Returns the value of thepropertyNamerecord component.- Returns:
- the value of the
propertyNamerecord component
-
propertiesMap
Returns the value of thepropertiesMaprecord component.- Returns:
- the value of the
propertiesMaprecord component
-
processContext
Returns the value of theprocessContextrecord component.- Returns:
- the value of the
processContextrecord component
-
innerSchemas
Returns the value of theinnerSchemasrecord component.- Returns:
- the value of the
innerSchemasrecord component
-